@@ -1,6 +1,6 @@
 # -*- coding: ISO-8859-1 -*-
 
-# Copyright (C) 2003 Jrg Lehmann <joerg@luga.de>
+# Copyright (C) 2003, 2007 Jrg Lehmann <joerg@luga.de>
 #
 # This file is part of PyTone (http://www.luga.de/pytone/)
 #
@@ -377,6 +377,7 @@ class general(configsection):
     debugfile = configpath("")
     randominsertlength = configfloat("3600")
     colorsupport = configalternatives("auto", ["auto", "on", "off"])
+    mousesupport = configboolean("on")
     layout = configalternatives("twocolumn", ["onecolumn", "twocolumn"])
     throttleoutput = configint("0")
     autoplaymode = configalternatives("off", ["off", "repeat", "random"])
@@ -402,6 +403,7 @@ class tag(configsection):
 
 
 class mixer(configsection):
+    type = configalternatives("external", ["external", "internal", "off"])
     device = configpath("/dev/mixer")
     channel = configstring("SOUND_MIXER_PCM")
     stepsize = configint("5")
@@ -418,7 +420,7 @@ class player(configsection):
         autoplay = configboolean("true")
 
         # only for internal player
-        driver = configalternatives("oss", ["alsa", "alsa09", "arts", "esd", "oss", "sun", "macosx"])
+        driver = configalternatives("oss", ["alsa", "alsa09", "alsa05", "arts", "esd", "oss", "sun", "macosx", "macosxau", "pulse"])
         device = configstring("/dev/dsp")
         bufsize = configint(100)
         crossfading = configboolean("true")
@@ -441,7 +443,7 @@ class player(configsection):
         autoplay = configboolean("true")
 
         # only for internal player
-        driver = configalternatives("oss", ["alsa", "alsa09", "arts", "esd", "oss", "sun", "macosx"])
+        driver = configalternatives("oss", ["alsa", "alsa09", "alsa05", "arts", "esd", "oss", "sun", "macosx", "pulse"])
         device = configstring("/dev/dsp1")
         bufsize = configint(100)
         crossfading = configboolean("true")
@@ -678,6 +680,7 @@ class keybindings(configsection):
         toggledelete = configkeys("D")
         search = configkeys("/ ctrl-s")
         repeatsearch = configkeys("ctrl-g")
+        focus = configkeys("f")
 
     class playlistwindow(configsection):
         selectnext = configkeys("KEY_DOWN j")
@@ -903,7 +906,7 @@ def checkoptions():
         songdb = database[databasename]
 
         if songdb.type == "local" and songdb.musicbasedir == "":
-            print ( "Please set musicbasedir in the [database.%s] section of the config file pytonerc\n"
+            print ( "Please set musicbasedir in the [database.%s] section of the config file ~/.pytone/pytonerc\n"
                     "to the location of your MP3/Ogg Vorbis files." % databasename )
             sys.exit(2)
 
@@ -913,16 +916,6 @@ def checkoptions():
                 sys.exit(2)
             dbfiles.append(songdb.dbfile)
 
-    # check whether oss module is present
-    try:
-        import ossaudiodev
-    except:
-        try:
-            import oss
-        except:
-            mixer.device = ""
-            log.warning("disabling mixer since neither ossaudiodev nor oss module is installed")
-
     # check ao options
     for aooption in player.main.aooptions.split() + player.secondary.aooptions.split():
         if aooption.count("=")!=1:
