@@ -1,6 +1,6 @@
 # -*- coding: ISO-8859-1 -*-
 
-# Copyright (C) 2002, 2003 Jrg Lehmann <joerg@luga.de>
+# Copyright (C) 2002, 2003, 2007 Jrg Lehmann <joerg@luga.de>
 #
 # This file is part of PyTone (http://www.luga.de/pytone/)
 #
@@ -80,6 +80,20 @@ class filelist(slist.slist):
             self._updatetop()
             self._notifyselectionchanged()
 
+    def focus_on(self, searchstring):
+        # remove any previous focus
+        if isinstance(self.dir[-1], item.focus_on):
+            self.dirup()
+        self.shistory.append((self.dir, self.selected, self.top))
+        songdbid = self.dir[-1].songdbid
+        # if filters apply, use them
+        try:
+            filters = self.dir[-1].filters
+        except AttributeError:
+            filters = None
+        self.dir = self.dir + [item.focus_on(songdbid, searchstring, filters)]
+        self.readdir()
+
     def selectionpath(self):
         return self.dir[-1].getheader(self.getselected())
 
@@ -150,7 +164,7 @@ class filelist(slist.slist):
             songs = [self.getselected()]
         for song in songs:
             song.toggledelete()
-        self.readdir()
+        self.updatedir()
         return True
 
     def rescanselection(self, force):
