@@ -36,7 +36,7 @@ def print_exc_plus():
         stack.append(f)
         f = f.f_back
     stack.reverse()
-    traceback.print_exc()
+    traceback.print_exc(file=sys.stdout)
     print "Locals by frame, innermost last"
     for frame in stack:
         print
@@ -49,5 +49,3 @@ def print_exc_plus():
                 print value
             except:
                 print "<ERROR WHILE PRINTING VALUE>"
-        
-
