@@ -1,6 +1,6 @@
 # -*- coding: ISO-8859-1 -*-
 
-# Copyright (C) 2002, 2003, 2004, 2005, 2006 Jrg Lehmann <joerg@luga.de>
+# Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007 Jrg Lehmann <joerg@luga.de>
 #
 # This file is part of PyTone (http://www.luga.de/pytone/)
 #
@@ -53,6 +53,7 @@ class hiddenfilter(filter):
     def __init__(self, indexname, indexid):
         filter.__init__(self, None, indexname, indexid)
 
+
 class urlfilter(hiddenfilter):
     def __init__(self, url):
         self.url = url
@@ -64,6 +65,7 @@ class urlfilter(hiddenfilter):
     def SQL_args(self):
         return [self.url]
 
+
 class compilationfilter(hiddenfilter):
     def __init__(self, iscompilation):
         self.iscompilation = iscompilation
@@ -121,9 +123,9 @@ class playlistfilter(hiddenfilter):
         return [self.playlist_id]
 
 
-class playedsongsfilter(hiddenfilter):
+class playedsongsfilter(filter):
     def __init__(self):
-        hiddenfilter.__init__(self, None, None)
+        filter.__init__(self, _("Played songs"), "playedsongs", "true")
 
     def SQL_WHERE_string(self):
         return "songs.playcount > 0"
@@ -135,6 +137,7 @@ class searchfilter(filter):
         filter.__init__(self, "Search: %s" % searchstring, None, searchstring)
 
     def SQL_WHERE_string(self):
+        #return "(songs.title LIKE ?)"
         return "(songs.title LIKE ?) OR (albums.name LIKE ?) OR (artists.name LIKE ?)"
 
     def SQL_args(self):
@@ -155,7 +158,7 @@ class tagfilter(filter):
         filter.__init__(self, name, indexname="tag", indexid=tag_name)
 
     def __repr__(self):
-        return "tag%s=%s" % (self.inverted and "!" or "", self.tag_name)
+        return "tag%r=%r" % (self.inverted and "!" or "", self.tag_name)
 
     def SQL_WHERE_string(self):
         if self.tag_id:
@@ -167,7 +170,9 @@ class tagfilter(filter):
 
     def SQL_args(self):
         if not self.tag_id:
-           return [self.tag_name]
+            return [self.tag_name]
+        else:
+            return []
 
 
 class podcastfilter(tagfilter):
@@ -374,7 +379,7 @@ class song(item):
         self.song_metadata = None
 
     def __repr__(self):
-        return "song(%s) in %s database" % (self.id, self.songdbid)
+        return "song(%r) in %r database" % (self.id, self.songdbid)
 
     # the following two methods have to be defined because we use song as a
     # member of a set in the autoregisterer
@@ -384,8 +389,6 @@ class song(item):
     def __eq__(self, other):
         return isinstance(other, song) and self.songdbid == other.songdbid and self.id == other.id
 
-    __str__ = __repr__
-
     def __getstate__(self):
         return (self.songdbid, self.id, self.album_id, self.artist_id, self.album_artist_id, self.date_played)
 
@@ -619,7 +622,7 @@ class artist(diritem):
         self.filters = filters.removed(compilationfilter).added(artistfilter(id))
 
     def __repr__(self):
-        return "artist(%s) in %s (filtered: %s)" % (self.name, self.songdbid, repr(self.filters))
+        return "artist(%r) in %r (filtered: %r)" % (self.name, self.songdbid, self.filters)
 
     def getname(self):
         return "%s/" % self.name
@@ -665,7 +668,7 @@ class album(diritem):
         self.filters = filters.added(albumfilter(id))
 
     def __repr__(self):
-        return "album(%s) in %s" % (self.id, self.songdbid)
+        return "album(%r) in %r" % (self.id, self.songdbid)
 
     class _orderclass:
         def cmpitem(self, x, y):
@@ -840,7 +843,7 @@ class lastplayedsongs(diritem):
     def __init__(self, songdbid, filters):
         self.songdbid = songdbid
         self.id = "lastplayedsongs"
-        self.filters = filters
+        self.filters = filters.added(playedsongsfilter())
         self.name = _("Last played songs")
 
     class _orderclass:
@@ -858,6 +861,9 @@ class lastplayedsongs(diritem):
     def getcontentsrecursiverandom(self):
         return hub.request(requests.getlastplayedsongs(self.songdbid, filters=self.filters, random=True))
 
+    def getinfo(self):
+        return _mergefilters([[self.name, "", "", ""]], self.filters[:-1])
+
 
 class topplayedsongs(diritem):
 
@@ -885,6 +891,9 @@ class topplayedsongs(diritem):
     def getcontentsrecursiverandom(self):
         return hub.request(requests.getsongs(self.songdbid, sort=self.order, filters=self.filters, random=True))
 
+    def getinfo(self):
+        return _mergefilters([[self.name, "", "", ""]], self.filters[:-1])
+
 
 class lastaddedsongs(diritem):
 
@@ -1092,7 +1101,7 @@ class filesystemdir(diritem):
                         song = hub.request(requests.autoregisterer_queryregistersong(self.songdbid, path))
                         if song:
                             items.append(song)
-                except (IOError, OSError) : pass
+                except (IOError, OSError): pass
         except OSError:
             return None
         items.sort(cmp=lambda x, y: cmp(x.getname(), y.getname()))
@@ -1165,22 +1174,18 @@ class basedir(totaldiritem):
         self.virtdirs.append(podcasts(self.songdbid, filters=self.filters))
         self.virtdirs.append(deleted(self.songdbid, filters=self.filters))
 
-        for filter in self.filters:
-            if isinstance(filter, tagfilter) and 0:
-                break
-        else:
-            self.virtdirs.append(tags(self.songdbid, self.songdbids, filters=self.filters))
-
-        for filter in self.filters:
-            if isinstance(filter, ratingfilter):
-                break
-        else:
+        if not self.filters.contains(searchfilter):
+             self.virtdirs.append(tags(self.songdbid, self.songdbids, filters=self.filters))
+        if not self.filters.contains(ratingfilter):
             self.virtdirs.append(ratings(self.songdbid, self.songdbids, filters=self.filters))
-        self.virtdirs.append(topplayedsongs(self.songdbid, filters=self.filters))
-        self.virtdirs.append(lastplayedsongs(self.songdbid, filters=self.filters))
+        if not self.filters.contains(playedsongsfilter):
+            self.virtdirs.append(topplayedsongs(self.songdbid, filters=self.filters))
+            self.virtdirs.append(lastplayedsongs(self.songdbid, filters=self.filters))
+            self.virtdirs.append(playedsongs(self.songdbid, nfilters=self.filters))
         self.virtdirs.append(lastaddedsongs(self.songdbid, filters=self.filters))
         self.virtdirs.append(randomsongs(self.songdbid, self.maxnr, filters=self.filters))
-        self.virtdirs.append(playlists(self.songdbid, filters=self.filters))
+        if not self.filters.contains(searchfilter):
+            self.virtdirs.append(playlists(self.songdbid, filters=self.filters))
         if len(self.songdbids) > 1:
             self.virtdirs.extend([basedir([songdbid], self.filters) for songdbid in self.songdbids])
 
@@ -1280,3 +1285,34 @@ class rating(index):
             description = "*" * r
         index.__init__(self, [songdbid], _("Rating:"), description, nfilters)
         self.id = r
+
+
+class playedsongs(index):
+
+    """ songs played at least once """
+
+    def __init__(self, songdbid, nfilters):
+        if nfilters is not None:
+            nfilters = nfilters.added(playedsongsfilter())
+        else:
+            nfilters = filters((playedsongsfilter(),))
+        index.__init__(self, [songdbid], _("Played songs:"), "[%s]" % _("Played songs"), nfilters)
+        self.name = _("Played songs")
+        self.id = "playedsongs"
+
+    def getinfo(self):
+        return _mergefilters([[self.name, "", "", ""]], self.filters[:-1])
+
+
+class focus_on(index):
+
+    """ songs filtered by search string """
+
+    def __init__(self, songdbid, searchstring, nfilters):
+        if nfilters is not None:
+            nfilters = nfilters.added(searchfilter(searchstring))
+        else:
+            nfilters = filters((searchfilter(searchstring),))
+        index.__init__(self, [songdbid], _("Search:"), searchstring, nfilters)
+        self.id = "search: %s" % searchstring
+
