@@ -1,6 +1,6 @@
 # -*- coding: ISO-8859-1 -*-
 
-# Copyright (C) 2002, 2003, 2004, 2005 Jrg Lehmann <joerg@luga.de>
+# Copyright (C) 2002, 2003, 2004, 2005, 2007 Jrg Lehmann <joerg@luga.de>
 #
 # This file is part of PyTone (http://www.luga.de/pytone/)
 #
@@ -343,8 +343,6 @@ class mainscreen:
         elif key in self.keybindings["showiteminfolong"]:
             self.iteminfowinlong.show()
         elif key in self.keybindings["showlyrics"]:
-            # XXX disabled at the moment
-            return 
             self.lyricswin.show()
         elif key in self.keybindings["togglelayout"]:
             self.layout = self.layout == "onecolumn" and "twocolumn" or "onecolumn"
