@@ -1,6 +1,6 @@
 # -*- coding: ISO-8859-1 -*-
 
-# Copyright (C) 2005, 2006 Jrg Lehmann <joerg@luga.de>
+# Copyright (C) 2005, 2006, 2007 Jrg Lehmann <joerg@luga.de>
 #
 # Ogg Vorbis interface by Byron Ellacott <bje@apnic.net>.
 #
@@ -387,7 +387,7 @@ def read_mp3_eyeD3_metadata(md, path):
             if length:
                 md.length = length
         md.lyrics = u"".join(mp3info.getLyrics())
-        md.comments = u"".join(mp3info.getComments())
+        md.comments = u"".join(map(lambda c: c.render(), mp3info.getComments()))
         md.bpm = mp3info.getBPM()
 
         for rva2frame in mp3info.frames["RVA2"]:
@@ -491,15 +491,21 @@ def read_vorbis_metadata(md, path):
             # REPLAYGAIN_ALBUM_PEAK=1.21822226
             try:
                 profile, type = name[11:].split("_")
-                basename = "replaygain_%s_" % profile.tolower()
+                basename = "replaygain_%s_" % profile.lower()
                 if type == "GAIN":
                    md[basename + "gain"] = float(value.split()[0])
-                   if not md.has_key(basename + "peak" % profile):
-                        md[basename + "peak"] = 1.0
+                   try:
+                       if md[basename + "peak"] is None:
+                           md[basename + "peak"] = 1.0
+                   except AttributeError:
+                       md[basename + "peak"] = 1.0
                 if type == "PEAK":
                    md[basename + "peak"] = float(value)
-                   if not md.has_key(basename + "gain"):
-                        md[basename + "gain"] = 0.0
+                   try:
+                       if md[basename + "gain"] is None:
+                           md[basename + "gain"] = 1.0
+                   except AttributeError:
+                       md[basename + "gain"] = 0.0
             except (ValueError, IndexError):
                 pass
 
