@@ -50,7 +50,7 @@ class playerwin(window.window):
             log.error(_("error '%s' occured during write to playerinfofile") % e)
             self.playerinfofd = None
         # we don't want to have the focus
-        self.panel.bottom()
+        self.bottom()
 
         channel.subscribe(events.playbackinfochanged, self.playbackinfochanged)
         channel.subscribe(events.keypressed, self.keypressed)
@@ -148,15 +148,20 @@ class playerwin(window.window):
         elif key in self.keybindings["playerspeedreset"]:
             hub.notify(events.playerspeedreset(self.playerid))
         elif key in self.keybindings["playerratecurrentsong1"]:
-            self.song.rate(1)
+            if self.song:
+                self.song.rate(1)
         elif key in self.keybindings["playerratecurrentsong2"]:
-            self.song.rate(2)
+            if self.song:
+                self.song.rate(2)
         elif key in self.keybindings["playerratecurrentsong3"]:
-            self.song.rate(3)
+            if self.song:
+                self.song.rate(3)
         elif key in self.keybindings["playerratecurrentsong4"]:
-            self.song.rate(4)
+            if self.song:
+                self.song.rate(4)
         elif key in self.keybindings["playerratecurrentsong5"]:
-            self.song.rate(5)
+            if self.song:
+                self.song.rate(5)
         else:
             return
         raise hub.TerminateEventProcessing
