@@ -29,12 +29,20 @@ class plugin:
         self.mainscreen = mainscreen
 
     def start(self):
-        """ start plugin after it has been configured """
-        pass
+        self.init()
+
+    def init(self):
+        """ initialize plugin after it has been configured """
 
 
 class threadedplugin(service.service, plugin):
 
     def __init__(self, channel, config, mainscreen):
         service.service.__init__(self, self.__class__.__name__)
-        plugin.__init__(self, channel, config, mainscreen)
+        # as independent thread, we have to use our own channel which has
+        # been created by the service constructor
+        plugin.__init__(self, self.channel, config, mainscreen)
+
+    def run(self):
+        self.init()
+        service.service.run(self)
