@@ -60,11 +60,13 @@ class songdb(service.service):
         if self.id != request.songdbid:
             raise hub.DenyRequest
         log.debug("dispatching %s" % `request`)
-        if isinstance(request, requests.getdatabaseinfo):
-            return ("remote", "%s" % str(self.networklocation))
         # we have to copy the request, because another thread may also access it
         request = copy.copy(request)
         request.songdbid = self.remotesongdbid
         result = self.networkchannel.request(request)
         log.debug("result %s" % `result`)
+        # we change the databasestats accordingly
+        if isinstance(request, requests.getdatabasestats):
+            result.type = "remote"
+            result.location = str(self.networklocation)
         return result
