@@ -1,7 +1,7 @@
 
 # -*- coding: ISO-8859-1 -*-
 
-# Copyright (C) 2002, 2003, 2004, 2006 Jrg Lehmann <joerg@luga.de>
+# Copyright (C) 2002, 2003, 2004, 2006, 2007 Jrg Lehmann <joerg@luga.de>
 #
 # This file is part of PyTone (http://www.luga.de/pytone/)
 #
@@ -25,7 +25,10 @@ import sys
 import random
 import time
 
-from pysqlite2 import dbapi2 as sqlite
+try:
+    import sqlite3 as sqlite
+except ImportError:
+    from pysqlite2 import dbapi2 as sqlite
 
 import events, hub, requests
 import errors
@@ -232,7 +235,7 @@ class songdb(service.service):
 
     def run(self):
         # self.con = sqlite.connect(":memory:")
-        log.debug("dbfile: '%s'" % self.dbfile)
+        log.debug("dbfile: '%r'" % self.dbfile)
         self.con = sqlite.connect(self.dbfile)
         self.con.row_factory = sqlite.Row
 
@@ -244,6 +247,7 @@ class songdb(service.service):
             self.con.executescript(create_tables)
             self._txn_commit()
             self.con.execute("PRAGMA user_version=%d" % self.currentdbversion)
+        log.debug("Starting db sevice")
         service.service.run(self)
         self.close()
 
@@ -273,7 +277,16 @@ class songdb(service.service):
     # resetting db stats
 
     def _clearstats(self):
-        pass
+        self._txn_begin()
+        try:
+            self.cur.execute("DELETE FROM playstats")
+            self.cur.execute("UPDATE songs SET playcount = 0, skipcount = 0, date_lastplayed = NULL ")
+
+        except:
+            self._txn_abort()
+            raise
+        else:
+            self._txn_commit()
 
     #
     # methods for adding, updating and deleting songs
@@ -385,11 +398,11 @@ class songdb(service.service):
             # hub.notify(events.songschanged(self.id))
 
             #for r in cur.execute("SELECT id, name FROM artists"):
-            #    log.info("AR: %s %s" % (r["id"], r["name"]))
+            #    log.info("AR: %r %r" % (r["id"], r["name"]))
             #for r in cur.execute("SELECT id, artist_id, name FROM albums"):
-            #    log.info("AL: %s %s %s" % (r["id"], r["artist_id"], r["name"]))
+            #    log.info("AL: %r %r %r" % (r["id"], r["artist_id"], r["name"]))
             #for r in cur.execute("SELECT id, title FROM songs"):
-            #    log.info("S: %s %s" % (r["id"], r["title"]))
+            #    log.info("S: %r %r" % (r["id"], r["title"]))
 
     def _delete_song(self, song):
         """delete song from database"""
@@ -483,7 +496,7 @@ class songdb(service.service):
                     song.artist_id = None
             if oldsong.album_artist != song.album_artist:
                 if song.album_artist:
-                    song.artist_id, newartist = self._queryregisterindex("artists", ["name"], [song.album_artist])
+                    song.album_artist_id, newartist = self._queryregisterindex("artists", ["name"], [song.album_artist])
                     changedartists |= newartist
                     if song.album:
                         song.album_id, newalbum = self._queryregisterindex("albums", ["artist_id", "name"], 
@@ -1033,14 +1046,18 @@ class songautoregisterer(service.service):
             # there is exactly one resulting song
             song = songs[0]
             song.song_metadata = self._request(requests.getsong_metadata(self.songdbid, song.id))
-            if force or song.song_metadata.date_updated < os.stat(path).st_mtime:
-                # the song has changed since the last update
-                newsong_metadata = metadata.metadata_from_file(relpath, self.basedir, self.tracknrandtitlere, self.postprocessors)
-                song.song_metadata.update(newsong_metadata)
-                self._notify(events.update_song(self.songdbid, song))
-                log.debug("registerer: song '%r' rescanned" % song_url)
-            else:
-                log.debug("registerer: not scanning unchanged song '%r'" % song_url)
+            try:
+                if force or song.song_metadata.date_updated < os.stat(path).st_mtime:
+                    # the song has changed since the last update
+                    newsong_metadata = metadata.metadata_from_file(relpath, self.basedir, self.tracknrandtitlere, self.postprocessors)
+                    song.song_metadata.update(newsong_metadata)
+                    self._notify(events.update_song(self.songdbid, song))
+                    log.debug("registerer: song '%r' rescanned" % song_url)
+                else:
+                    log.debug("registerer: not scanning unchanged song '%r'" % song_url)
+            except (IOError, OSError, RuntimeError):
+                log.debug("registerer: song '%r' can no longer be read. deleting it from db" % song_url)
+                self._notify(events.delete_song(self.songdbid, song))
         else:
             # song was not stored in database
             newsong_metadata = metadata.metadata_from_file(relpath, self.basedir, self.tracknrandtitlere, self.postprocessors)
@@ -1146,8 +1163,9 @@ class songautoregisterer(service.service):
             log.info(_("database %r: finished rescanning %d songs") % (self.songdbid, len(event.songs)))
 
     def autoregisterer_queryregistersong(self, request):
-        if self.songdbid == request.songdbid:
-            try:
-                return self._registerorupdatesong(request.path, force=True)
-            except:
-                return None
+        if self.songdbid != request.songdbid:
+            raise hub.DenyRequest
+        try:
+            return self._registerorupdatesong(request.path, force=False)
+        except:
+            return None
